| AHA | R Documentation |
Wrapper function for an implementation of All-H Analyzer (AHA) in R. Can be used to compare outputs between AHA and salmonMSE.
AHA(SOM, ngen = 100, silent = FALSE)
SOM |
An object of class SOM |
ngen |
Integer, the number of generations for which to run the simulation |
silent |
Logical, indicates whether to silence messages to the R console |
A named list containing vectors of state variables (by simulation, population, and generation). See SMSE object description.
Hatchery Scientific Review Group. 2020. All-H Analyzer Tool Guide and Documentation. May 2020.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.