| Bio-class | R Documentation |
"Bio"The component of the operating model that controls biological dynamics, i.e., natural production.
Various parameters can be stochastic (length nsim) or input as a single numeric
(value identical across all simulations).
NameCharacter. Identifying name
maxageInteger. The maximum age of the population age structure.
n_gInteger. Number of life history groups within a cohort. Life history groups (LHGs) are sub-units of a cohort that have different marine survival. Default is 1.
p_LHGThe proportion of the total egg production assigned to each life history group within a cohort. For example,
if Bio@n_g <- 2, then Bio@p_LHG <- c(0.9, 0.1), then 90 percent of the egg production in the first population is assigned to the first life history group and
ten percent to the second LHG. Default is rep(1/Bio@n_g, Bio@n_g)
p_matureEither vector by age (length maxage) or an array with dimension [nsim, maxage, proyears]. The proportion mature by age.
SRrelCharacter, stock-recruit relationship for density-dependent smolt production from fry. Either "BH" (Beverton-Holt) or "Ricker".
Not used if habitat component is used. See Habitat object.
capacityVector length nsim. Only used if SRrel = "BH". The asymptote, i.e., maximum juvenile production, of the Beverton-Holt stock-recruit function for density-dependent natural smolt production from egg production.
Units of smolts. Not used if habitat component is used.
kappaVector length nsim. The adult productivity ratio for the stock-recruit function. Units of recruits per spawner.
Natural per-capita production of recruits as the population approaches zero (density-independent component).
Not used if habitat component is used.
SmaxVector length nsim. Only used if SRrel = "Ricker". The spawner abundance that maximizes smolt production in the Ricker stock-recruit function. Units of spawners.
Not used if habitat component is used.
phiOptional, vector length nsim. Egg production per smolt at unfished replacement. Units of egg per smolt.
Converts productivity from units of recruits/spawner (kappa) to smolts/egg (alpha), where alpha = kappa/phi. In simple models,
phi is the product of marine survival, fecundity, and proportion female. If not provided, phi will be calculated from Mjuv_NOS, p_mature, s_enroute, p_female, fec, and p_LHG corresponding
to the first year and weighted by life history groups. Not used if habitat component is used.
tauOptional, vector length nsim. Spawner per smolt at unfished replacement, only used if SRrel = "Ricker". Units of spawner per smolt.
Used to convert Smax to Emax, the corresponding egg production that maximizes smolt production, where Emax = Smax * phi/tau and the Ricker parameter beta = 1/Emax. In simple models,
tau is the product of marine survival and proportion female. If not provided, tau will be calculated from Mjuv_NOS, p_mature, s_enroute, p_female, and p_LHG corresponding
to the first year and weighted by life history groups. Not used if habitat component is used.
Mjuv_NOSEither vector by age (length maxage-1) or an array with dimension [nsim, maxage-1, proyears, n_g].
Natural mortality of immature natural origin fish, the value for the first age represents natural mortality from age 1 to 2, second age is mortality from age 2 to 3, and so on.
To replicate the SAR parameter of a stage-specific model, set Mjuv_NOS[a] = -log(SAR) where a is the age class prior to maturation (and zero for all other ages).
fecVector by age (length maxage) or an array with dimension [nsim, maxage, proyears]. Female fecundity of natural origin spawners.
p_femaleNumeric. The proportion of females in the spawning population. Default is 0.5. Can also be a vector [maxage] (for situations where older spawners are predominantly female)
s_enrouteNumeric. Survival of escapement to the spawning grounds (for spawning and for broodtake). Default is 1.
Objects can be created by calls of the form new("Bio")
showClass("Bio")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.