| CM_MSY | R Documentation |
Plots time series of MSY reference points. Not used in automated reporting as they can be computationally expensive and individual case studies may require specific assumptions.
CM_MSY(
report,
d,
year1 = 1,
simple = FALSE,
index = NULL,
mean_bio = FALSE,
type = c("spawner", "egg", "u"),
maximize = c("MSY", "MER"),
AEQ = TRUE,
ncores = 1,
na.rm = FALSE
)
CM_Sgen(
report,
d,
year1 = 1,
simple = FALSE,
index = NULL,
mean_bio = FALSE,
ncores = 1,
na.rm = FALSE
)
report |
List, output of state variables from individual MCMC samples, obtained with |
d |
List of data variables, obtained with |
year1 |
Numeric, first year of model |
simple |
Logical, whether to use Ricker lambert equations for MSY reference points (TRUE) or age-structured optimization (FALSE) |
index |
Integer vector to subset years with which to calculate reference points. Can be used
to reduce computation or average biological parameters from a subset of years, see |
mean_bio |
Logical, whether to average the natural mortality and maturity parameters across
years indicated in |
type |
Character, the type of reference point to calculate |
maximize |
Character, whether the numerical optimization maximizes catch (MSY) or excess recruitment (MER). For testing only,
should not impact results. Only used if |
AEQ |
Logical, whether to use adult equivalents when calculating MSY for preterminal fisheries#' Only used if |
ncores |
Numeric, number of processors for parallel computation. Useful if calculating numerically for many MCMC samples |
na.rm |
Logical, whether to exclude negative values from the median in figures |
ggplot object
CM_prod() CM_Srep() .CM_MSY()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.