| Habitat-class | R Documentation |
"Habitat"The component of the operating model that controls survival in the freshwater environment. Includes changes in survival from either environmental/climate effects or habitat mitigation.
NameCharacter. Identifying name
use_habitatLogical. If TRUE, utilize stage-specific density-dependent functions from egg production from incubation mortality,
egg-to-fry production, and fry-to-smolt production with annual deviations. Otherwise, the density-dependence is modeled for egg-to-smolt survival.
See Bio object.
prespawn_relCharacter, density-dependent function for pre-spawn mortality, e.g., for spawners to reach spawning sites. Choices are "BH" (Beverton-Holt) or "HS" (hockey stick). Default is "BH".
prespawn_prodNumeric, productivity for pre-spawn mortality. Default is 1.
Default if Inf.
prespawn_capacityNumeric, capacity for pre-spawn mortality. Default is Inf, i.e., density-independence.
Default is Inf.
egg_relCharacter, density-dependent function for egg production from total spawning output. Choices are "BH" (Beverton-Holt) or "HS" (hockey stick). Default is "BH".
egg_prodNumeric, productivity for egg production from total spawning output (incubation). Default is 1.
Default if Inf.
egg_capacityNumeric, capacity for egg production from total spawning output (incubation). Default is Inf, i.e., density-independence.
Default is Inf.
fry_relCharacter, density-dependent function for egg-to-fry production. Choices are "BH" (Beverton-Holt) or "HS" (hockey stick). Default is "BH".
fry_prodNumeric between 0-1, productivity for egg production from total spawning output, i.e., maximum survival as egg production approaches zero. Default is 0.4.
fry_capacityNumeric, capacity for fry production from egg production. Default is Inf, i.e., for density-independence.
Default is Inf.
fry_sdevMatrix [nsim, proyears], deviations from the density-dependent egg-fry survival. Can be utilized to incorporate
time-varying environmental, climate, or habitat mitigation effects. Default is matrix(1, nsim, proyears).
smolt_relCharacter, density-dependent function for fry-to-smolt production. Choices are "BH" (Beverton-Holt) or "HS" (hockey stick). Default is "BH".
smolt_prodNumeric between 0-1, productivity for smolt production from fry, i.e., maximum survival as fry production approaches zero. Default is 1.
smolt_capacityNumeric, capacity for smolt production from fry production. Set to Inf for density-independence.
Default is Inf.
smolt_sdevMatrix [nsim, proyears], deviations from the density-dependent fry-smolt survival. Can be utilized to incorporate
time-varying environmental, climate, or habitat mitigation effects. Default is matrix(1, nsim, proyears).
Objects can be created by calls of the form new("Habitat")
showClass("Habitat")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.