| Hatchery-class | R Documentation |
"Hatchery"The component of the operating model that controls the hatchery management and in-river removals.
Various parameters can be stochastic (length nsim) or input as a single numeric
(value identical across all simulations).
A description of the fitness parameters and hatchery dynamics is available in the online documentation.
NameCharacter. Identifying name
n_rInteger. Number of release strategies, sub-groups of fish with different survival schedules. Default is one.
n_yearlingVector length n_r. The target number of yearlings released by release strategy. No hatchery is modeled if sum(n_yearling, n_subyearling) = 0.
are zero. Default is zero. Yearlings are differentiated from sub-yearlings only in the hatchery survival parameter, e.g., lower egg-yearling survival than for egg-subyearling, so more brood is needed for yearling releases.
n_subyearlingVector length n_r. The target number of subyearlings released. No hatchery is modeled if sum(n_yearling, n_subyearling) = 0 are zero.
Default is zero. Yearlings are differentiated from sub-yearlings only in the hatchery survival parameter, e.g., lower egg-yearling survival than for egg-subyearling, so more brood is needed for yearling releases.
yearling_DDLogical, whether freshwater yearling survival after release is density-dependent, in competition with natural-origin juveniles. Default is FALSE. Likely relevant only for stream types where there is substantial residence time before outmigration.
subyearling_DDLogical, whether freshwater subyearling survival after release is density-dependent, in competition with natural-origin juveniles. Default is FALSE. Likely relevant only for stream types where there is substantial residence time before outmigration.
s_prespawnNumeric. The survival of broodtake prior to egg production. 1 - s_prespawn is the proportion of fish not used for hatchery purposes, e.g., mortality or other resesarch purposes.
Used to back-calculate the broodtake from n_yearling and n_subyearling. Default is 1.
s_egg_smoltNumeric. The survival of eggs to the smolt life stage (for yearling release).
Used to back-calculate the broodtake from n_yearling and n_subyearling. Default is 1.
s_egg_subyearlingNumeric. The survival of eggs to subyearling life stage (for subyearling release).
Used to back-calculate the broodtake from n_yearling and n_subyearling. Default is 1.
Mjuv_HOSEither vector by age (length maxage-1) or an array with dimension [nsim, maxage-1, proyears, n_r].
Natural mortality of immature hatchery origin fish.
To replicate the SAR parameter of a stage-specific model, set Mjuv_HOS[a] = -log(SAR) for the age class prior to maturation (and zero for all other ages).
p_mature_HOSVector by age (length maxage) or an array with dimension [nsim, maxage, proyears, n_r] for the maturity of hatchery spawners.
Default is set equal to Bio@p_mature for all release strategies.
stray_externalMatrix by age (length maxage) and release strategy n_r that denotes the annual number of hatchery origin strays from other populations/systems
not included in the operating model. Default is zero. External strays are added at the escapement life stage, assumed unmarked. For multi-population models with straying within the system, see also SOM@stray matrix.
gammaNumeric. The relative reproductive success of hatchery origin spawners (relative to natural origin spawners). Default is 1.
mNumeric. The mark rate of hatchery origin fish, which affects selective broodtake and fishery retention if mark-selective fishing is utilized.
Set m = 1 for AHA compatibility with ptarget_NOB. Default is zero.
f_broodFunction that calculates the natural origin brood and hatchery origin brood from the escapement (after en-route mortality). Function should be of the form
function(NO, HO, stray, m) {return(list(NOB, HOB_marked, HOB_unmarked, HOB_stray))}. Allows for bespoke rules for broodtake.
brood_importNot used if f_brood is provided Matrix by age (length maxage) for the number of annual imported hatchery origin broodstock. Egg production is weighted by fec_brood.
To meet hatchery production target releases, imported brood and local marked brood are used indiscriminately. Default imported brood is zero.
pmax_escNot used if f_brood is provided Numeric. The maximum proportion of total escapement (after en route mortality) that could be used as broodtake. Set to 1 for AHA compatibility. Default is 0.75.
pmax_NOBNot used if f_brood is provided Numeric. The maximum proportion of the natural origin escapement (after en route mortality and pmax_esc) to be used as broodtake. If broodstock
is limited by pmax_esc < 1, then this parameter should be 1. Default is 1.
ptarget_NOBNot used if f_brood is provided Numeric. The target proportion of the natural origin broodtake relative to the overall broodtake, assuming the mark rate is 1 and natural origin fish
can be identified in the hatchery. The realized proportion may be lower if there are insufficient natural origin escapement. If the mark rate < 1, then
this target proportion identifies the proportion of unmarked fished in the broodtake. If mark rate = 0, then pNOB is equal to the proportion in the escapement. Default is 0.9.
phatcheryNot used if f_brood is provided Numeric. Optional parameter (default is NA). If set to a numeric between 0-1, this value is the proportion of the hatchery origin escapement that return to the hatchery, for example, by removal from spawning grounds
or swim-in facilities. These fish are available for broodtake. None of these fish will spawn in the natural environment.
With the default option, NA allows all hatchery origin escapement to be available for brood (the remainder go to the spawning grounds).
premove_HOSNumeric or function. The target proportion of the hatchery origin fish to be removed from the spawning grounds (in order to
ensure a high proportion of NOS). The proportion of hatchery fish removed is discounted by the mark rate, i.e., p = premove_HOS * m.
The removed hatchery-origin fish do not spawn and are not available for broodtake. A value less than one can represent
imperfect implementation of weir removal. Default is zero. This slot can take a function that returns the proportion (p) based on hatchery-origin and natural-origin abundance (after brood removal), thus
allowing for bespoke rules for in-river harvest. The function should be of the form: function(NO, HO, m) {return(p)}.
premove_NOSNumeric or function. The target proportion of the natural origin fish to be removed from the spawning grounds, for example, through an in-river fishery.
The proportion of natural fish removed is adjusted by the mark rate, i.e., p = premove_NOS * (1-m).
Default is zero. This slot can take a function that returns the proportion (p) based on hatchery-origin and natural-origin abundance (after brood removal), thus
allowing for bespoke rules for in-river harvest. The function should be of the form: function(NO, HO, m) {return(p)}.
fec_broodVector length maxage or an array with dimension [nsim, maxage, proyears]. The fecundity schedule of broodtake to calculate the total egg production for the hatchery. If missing, uses Bio@fec.
p_female_broodNumeric or vector maxage. Proportion of females of brood used to calculate hatchery egg production, for situations with sex-selective brood. If missing, uses Bio@p_female.
fitness_typeCharacter vector length 2. The fitness function to apply in the natural and hatchery environment, respectively. For each, either "Ford" or "none".
thetaVector length 2. The optimum phenotype value for the natural and hatchery environments.
rel_lossVector length 3. The loss in fitness apportioned among the egg, fry, and smolt life stages which reduces survival. Theoretically, the three values should sum to 1. Alternatively, set to zero to set fitness loss to zero for that specific life stage (survival is one).
zbar_startVector length 2. The mean phenotype value in the natural and hatchery populations at the start of the projection. Alternatively,
an array by dimension [nsim, maxage, 2], where the age slot corresponds to cohort.
fitness_varianceNumeric. The variance (omega-squared) of the fitness function. Assumed identical between the natural and hatchery environments. Default is 100.
phenotype_varianceNumeric. The variance (sigma-squared) of the phenotypic trait (theta). Assumed identical between the natural and hatchery environments. Default is 10.
heritabilityNumeric or vector length [nsim]. The heritability (h-squared) of the phenotypic trait. Between 0-1. Default is 0.5
fitness_floorNumeric. The minimum fitness value in the natural and hatchery environments, i.e., fitness cannot drop below this threshold. Default is 0.5.
Objects can be created by calls of the form new("Hatchery")
showClass("Hatchery")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.