| SOM-class | R Documentation |
"SOM"An object containing all the parameters for a salmon operating model (SOM).
NameCharacter. Identifying name
nsimInteger. Number of simulations
proyearsInteger. The number of projected years
seedInteger. A random seed to ensure users can reproduce results exactly
BioBio object informing biological parameters and natural production. Provide a list of Bio objects for multi-population models.
HabitatHabitat object containing management levers for controlling survival in the freshwater environment. Provide a list of Habitat objects for multi-population models.
HatcheryHatchery object containing management levers for hatchery production and in-river removals. Provide a list of Hatchery objects for multi-population models.
HarvestHarvest object containing management levers for marine harvest. Provide a list of Harvest objects for multi-population models.
HistoricalHistorical object to inform historical reconstruction and informing starting abundance for the projection. Provide a list of Historical objects for multi-population models.
strayMatrix [np, np] where np = length(Bio) and row p indicates the re-assignment of hatchery fish to each population when they mature (at the recruitment life stage). For example,
SOM@stray <- matrix(c(0.75, 0.25, 0.25, 0.75), 2, 2) indicates that 75 percent of mature fish return to their natal river and 25 percent stray in both populations. By default, an identity matrix is used (no straying).
Objects can be created by calls of the form
new("SOM", Bio, Habitat, Hatchery, Harvest, Historical).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.