| calc_SRR | R Documentation |
Calculates the abundance of survivors after applying either a Beverton-Holt or Ricker stock-recruit relationship.
calc_SRR(N1, N2 = N1, p, capacity, type = c("BH", "Ricker", "HS"))
N1 |
Numeric, the initial abundance that scales the density-independent survival term |
N2 |
Numeric, the initial abundance that scales the density-dependent survival term |
p |
Numeric, the productivity parameter that sets the maximum survival as the initial abundance approaches zero |
capacity |
Numeric, the capacity parameter that set the maximum survivors |
type |
Character, the functional form of the stock-recruit relationship |
The Beverton-Holt stock recruit relationship is of the following form:
\textrm{Smolt} = \dfrac{\alpha N_1}{1 + \beta N_2}
where \alpha = P, \beta = P/C.
The Ricker stock recruit relationship is of the following form:
\textrm{Smolt} = \alpha N_1 \exp(-\beta N_2)
where \alpha = P, \beta = P/(Ce), e is Euler's number.
Productivity P is in terms of abundance per unit of N_1 and N_2.
The hockey stick is of the following form:
\textrm{Smolt} =
\begin{cases}
p N_1 &, N_1 \le \frac{N_1}{N_2} \times C\\
\frac{N_1}{N_2} \times C &, \textrm{otherwise}
\end{cases}
Numeric, the abundance of survivors
calc_SRRpars()
N1 <- 100
N2 <- 200
p <- 10
capacity <- 250
calc_SRR(N1, N2, p, capacity, type = "BH")
# Validation
SRRpars <- calc_SRRpars(p, capacity, type = "BH")
a <- SRRpars[1]
b <- SRRpars[2]
a * N1/(1 + b * N2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.