calc_SRRpars: Convert density-dependent survival parameters

View source: R/SRR.R

calc_SRRparsR Documentation

Convert density-dependent survival parameters

Description

Converts from capacity/productivity parameters to alpha/beta stock-recruit parameters where productivity is in terms of smolts per spawner and alpha is terms of smolts per egg.

Usage

calc_SRRpars(p, capacity, f = 1, p_female = 1, type = c("BH", "Ricker", "HS"))

Arguments

p

Numeric, the productivity parameter that sets the maximum survival as the initial abundance approaches zero

capacity

Numeric, the capacity parameter that set the maximum survivors

f

Fecundity, the spawning output per mature female

p_female

The proportion of females per spawner

type

Character, the functional form of the stock-recruit relationship

Details

\alpha = \dfrac{P}{f \times p_{female}}

For the Beverton-Holt stock recruit relationship:

\beta = \dfrac{\alpha}{C}

For the Ricker stock recruit relationship:

\beta = \dfrac{\alpha}{Ce}

, e is Euler's number.

Value

Numeric vector length 2 for alpha and beta value, respectively

See Also

calc_SRR()

Examples


N1 <- 100
N2 <- 200
p <- 10
capacity <- 250

calc_SRRpars(p, capacity, type = "BH")

salmonMSE documentation built on Aug. 20, 2026, 5:09 p.m.