| calc_broodtake | R Documentation |
Internal functions to calculate broodtake with various constraints, called by brood_func().
calc_broodtake() is a wrapper function.
calc_broodtake_custom() uses a user-provided function to generate brood numbers and adjusts
downwards if egg production exceeds the target.
.broodtake_func() is the optimization function used to calculate broodtake
calc_broodtake(
NO,
HO,
stray,
brood_import,
ptarget_NOB,
pmax_NOB,
phatchery,
egg_target,
p_female,
fec,
s_prespawn,
m
)
calc_broodtake_custom(
f_brood,
NO,
HO,
stray,
p_female,
fec,
s_prespawn,
m,
egg_target
)
.broodtake_func(
ptake_unmarked,
NO,
HO,
stray,
brood_import,
phatchery,
p_female,
fec,
egg_target,
s_prespawn,
ptarget_NOB,
m = 1,
opt = TRUE
)
NO |
Matrix |
HO |
Matrix |
stray |
Matrix |
brood_import |
Vector |
ptarget_NOB |
Numeric, target proportion of |
pmax_NOB |
Numeric, maximum proportion of |
phatchery |
Numeric, proportion of |
egg_target |
Numeric, target egg production from which to back-calculate brood numbers |
p_female |
Vector |
fec |
Vector |
s_prespawn |
Numeric, survival of brood prior to egg production |
m |
Numeric, mark rate of |
f_brood |
Function that calculates the brood numbers |
ptake_unmarked |
Numeric, proportion of unmarked fish used for brood |
opt |
Logical, whether the function is used for optimization (TRUE) or reporting (FALSE) |
calc_broodtake() returns a list from .broodtake_func()
calc_broodtake_custom() returns a named list, same format as calc_broodtake()
.broodtake_func() returns a numeric if opt = TRUE: log(p_unmarked) - log(ptarget_NOB), otherwise
a named list of brood and egg production.
egg_NOB Matrix [nage, n_g]
egg_HOB_unmarked Matrix [nage, n_r] (including strays)
egg_HOB_marked Matrix [nage, n_r]
egg_HOB_import Vector [nage]
ptake_unmarked Numeric
ptake_marked Numeric
pNOB Numeric
NOB Numeric
HOB_unmarked Matrix [nage, n_r]
HOB_marked Matrix [nage, n_r]
HOB_import Matrix [nage, n_r]
HOB_stray Vector [nage]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.