| calc_ref | R Documentation |
Calculate MSY and Sgen reference points for the operating model. Uses the biological parameters (maturity, natural mortality) in the last year of the projection.
calc_MSY() calculates the MSY reference points from a set of biological and fishery parameters
calc_Sgen() calculates the Sgen, the spawner abundance that would reach the spawner abundance at MSY after one generation without fishing
calc_ref() is a wrapper function that calculates MSY and Sgen for an operating model
calc_ref(SOM, rel_F, check = TRUE, maximize = c("MSY", "MER"), AEQ = TRUE)
calc_MSY(
Mjuv,
fec,
p_female,
rel_F,
vulPT,
vulT,
p_mature,
s_enroute,
n_g = 1,
p_LHG = 1,
SRRpars,
maximize = c("MSY", "MER"),
AEQ = TRUE,
F_search = c(1e-08, 5)
)
calc_Sgen(
Mjuv,
fec,
p_female,
rel_F,
vulPT,
vulT,
p_mature,
s_enroute,
n_g = 1,
p_LHG = 1,
SRRpars,
SMSY,
F_search = c(1e-08, 100),
nyears
)
SOM |
An object of class SOM |
rel_F |
Numeric length 2, indicates the relative effort in the preterminal and terminal fisheries, with a maximum value of 1.
The default is |
check |
Logical, whether to check the SOM object using |
maximize |
Character, whether the MSY calculation is the optimum that maximizes catch ( |
AEQ |
Logical, whether to maximize preterminal catch in terms of adult equivalents |
Mjuv |
Numeric |
fec |
Numeric |
p_female |
Numeric for proportion female spawners |
vulPT |
Numeric |
vulT |
Numeric |
p_mature |
Numeric |
s_enroute |
Numeric for en-route survival of escapement to spawning grounds |
n_g |
Integer, number of life history groups within a cohort |
p_LHG |
Numeric |
SRRpars |
Data frame, one row, that contains the stock recruit parameters that predicts density-dependent survival at the egg-smolt life stage |
F_search |
Numeric, length 2 for the range of F values to search for the instantaneous fishing mortality that produces MSY |
SMSY |
Numeric, spawning abundance at MSY |
nyears |
Integer, number of years to project the population with no fishing to reach |
calc_MSY returns a vector of various state variables (catch, exploitation rate, egg production, spawners) at MSY
calc_Sgen returns a numeric
calc_ref returns a list by stock, each containing a matrix of MSY state variables and Sgen by simulation
calc_Smsy_Ricker()
ref_simple <- calc_ref(simple_SOM)
ref_multi <- calc_ref(multi_SOM)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.