Calculate smolt production from base stock-recruit parameters and fitness loss
calc_smolt(
N1,
N2 = N1,
kappa,
capacity,
Smax,
phi = 1,
fitness_loss = 1,
SRrel = c("BH", "Ricker"),
per_recruit = FALSE
)Numeric
Egg production for the density-independent component of the stock-recruit relationship. Can be the number of spawners if phi = 1
and Smax is in units of spawners.
Egg production for the density-dependent component of the stock-recruit relationship (only used if per_recruit = FALSE)
Base productivity parameter
Base capacity parameter if SRrel = "BH"
Base Smax parameter if SRrel = "Ricker"
Unfished egg per smolt (1/phi is the replacement line)
Survival term to reduce smolt production due to fitness, between 0-1
Character for the stock-recruit function
Logical, whether N1 is a per recruit quantity (TRUE) or in absolute numbers (FALSE)