| compare | R Documentation |
Generate a markdown report for multiple model runs to compare scenarios. 3-5 is likely the ideal number of scenarios for comparison.
compare(
SMSE_list,
names,
col_vec,
filename = "SMSEcompare",
dir = tempdir(),
open_file = TRUE,
render_args = list(),
...
)
SMSE_list |
List of SMSE objects |
names |
Character vector |
col_vec |
Character vector |
filename |
Character string for the name of the markdown and HTML files. |
dir |
The directory in which the markdown and HTML files will be saved. |
open_file |
Logical, whether the HTML document is opened after it is rendered. |
render_args |
List of arguments to pass to |
... |
Additional arguments (not used) |
Returns invisibly the output of rmarkdown::render(), typically the path of the output file
report()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.