| compare_spawners | R Documentation |
Create figures that compare results across two dimensions
compare_spawners(SMSE_list, Design, prop = FALSE, FUN = median)
compare_fitness(SMSE_list, Design, FUN = median)
compare_escapement(SMSE_list, Design, FUN = median)
SMSE_list |
A list of SMSE objects returned by |
Design |
A data frame with two columns that describes the factorial design of the simulations. Used to label the figure.
Rows correspond to each object in |
prop |
Logical, whether to plot absolute numbers over proportions |
FUN |
Summarizing function across simulations, typically |
compare_spawners() generates a time series of the composition of spawners
compare_fitness() generates a time series of metrics (fitness, PNI, pHOS, and pWILD) related to hatchery production
compare_escapement() generates a time series of the proportion of spawners and broodtake to escapement
A ggplot object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.