define_hatchery_args: Create list of parameters

View source: R/check_SOM.R View source: R/salmonMSE.R

define_hatchery_argsR Documentation

Create list of parameters

Description

Internal functions that convert the operating model inputs into a list or data frame of parameters to pass on to other internal functions.

Usage

define_hatchery_args(SOM)

define_habitat_args(SOM)

define_fitness_args(SOM)

define_SRRpars(SOM)

Arguments

SOM

SOM operating model object

Value

define_hatchery_args() returns a length nstocks of hatchery parameters, in-river removals, and behavior of hatchery-origin fish in the freshwater environment (fecundity, reproductive success, etc.)

define_habitat_args() returns a list of Habitat objects.

define_fitness_args() returns a length nstocks of fitness parameters.

define_SRRpars_args() returns a length nstocks, each of which is a data frame of stock-recruit parameters.


salmonMSE documentation built on Aug. 20, 2026, 5:09 p.m.