| .CM_prod | R Documentation |
Internal functions that calculate productivity (.CM_prod()) and reference points (.CM_MSY())
from the conditioning model.
These functions can be used to calculate values for a subset of years (productivity can vary
in time with natural mortality and maturity), or from average biological parameters in a subset of years.
.CM_prod(report, d, index = NULL, mean_bio = FALSE)
.CM_Srep(report, d, index = NULL, mean_bio = FALSE, type = c("spawner", "egg"))
.CM_MSY(
report,
d,
simple = TRUE,
index = NULL,
mean_bio = FALSE,
type = c("spawner", "egg", "u", "Sgen"),
AEQ = TRUE,
maximize = c("MSY", "MER"),
ncores = 1
)
report |
List, output of state variables from individual MCMC samples, obtained with |
d |
List of data variables, obtained with |
index |
Integer vector to subset years with which to calculate reference points. Can be used
to reduce computation or average biological parameters from a subset of years, see |
mean_bio |
Logical, whether to average the natural mortality and maturity parameters across
years indicated in |
type |
Character, the type of reference point to calculate |
simple |
Logical, whether to use Ricker lambert equations for MSY reference points (TRUE) or age-structured optimization (FALSE) |
AEQ |
Logical, whether to use adult equivalents when calculating MSY for preterminal fisheries#' Only used if |
maximize |
Character, whether the numerical optimization maximizes catch (MSY) or excess recruitment (MER). For testing only,
should not impact results. Only used if |
ncores |
Numeric, number of processors for parallel computation. Useful if calculating numerically for many MCMC samples |
Matrix, dimension [length(index), length(report)]. If mean_bio = TRUE, matrix has 1 row.
CM_MSY()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.