| .egg_func | R Documentation |
Simple wrapper function to calculate hatchery egg production
.egg_func(
ptake = 1,
N,
gamma = 1,
fec,
p_female,
s_prespawn,
val = 0,
opt = TRUE
)
ptake |
Numeric, proportion of spawners that spawn |
N |
Numeric, spawners |
gamma |
Numeric, relative reproductive success of spawners |
p_female |
Numeric, proportion female |
s_prespawn |
Numeric, survival of spawners prior to egg production |
val |
Numeric, target egg production. Used to optimize for |
opt |
Logical, whether the function is used to optimize for |
Numeric
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.