SOM2MOM() converts a salmon operating model (SOM) to a multi-stock operating model (MSEtool::MOM)
make_Stock() creates the MSEtool::Stock object (openMSE) corresponding to salmon life stage
make_Fleet() creates the MSEtool::Fleet object (openMSE) corresponding to the fishery that interacts with the various salmon life stages
multiHist2SHist() converts the openMSE historical reconstruction into a salmon Hist object (SHist)
MMSE2SMSE() converts the openMSE projection output, along with additional state variables recorded in salmonMSE_env, into a salmon MSE object (SMSE)
make_Harvest_MMP() creates a multi-stock management procedure for the harvest component of the operating model by
specifying exploitation rates through updating the formal arguments for Harvest_MMP()
salmonMSE() is the wrapper function that coordinates the simulation and the output.
make_Harvest_MMP(SOM, check = TRUE)MMSE2SMSE(MMSE, SOM, Harvest_MMP, N, stateN, Ford, H, stateH)
SOM2MOM(SOM, check = TRUE)
make_Stock(
SOM,
s = 1,
g = 1,
r = 1,
NOS = TRUE,
stage = c("immature", "return", "escapement")
)
make_Fleet(SOM, s, NOS = TRUE, stage = c("immature", "return", "escapement"))
multiHist2SHist(multiHist, SOM, check = TRUE)
make_Harvest_MMP: Function of class "MMP" by updating the formal arguments for Harvest_MMP()
MMSE2SMSE: SMSE object
SOM2MOM: MSEtool::MOM object
make_Stock: List containing a MSEtool::Stock object and accompanying custom parameters list
make_Stock: List containing a MSEtool::Fleet object and accompanying custom parameters list
multiHist2SHist: SHist object
An object of class SOM
Logical, whether to check the SOM object using check_SOM()
Object of class MSEtool::MMSE returned from MSEtool
Optional harvest function created by make_Harvest_MMP()
Data frame of natural origin abundance at age saved in the salmonMSE_env environment during the simulation
Data frame of natural origin state variables saved in the salmonMSE_env environment during the simulation
Data frame of phenotypic trait values saved in the salmonMSE_env environment during the simulation
Data frame of hatchery origin abundance at age saved in the salmonMSE_env environment during the simulation
Data frame of hatchery origin state variables saved in the salmonMSE_env environment during the simulation
Integer, the population integer for which to create the Stock or Fleet object
Integer, the life history group for which to create the Stock object. Not relevant if NOS = FALSE
Integer, the hatchery release group for which to create the Stock object. Not relevant if NOS = TRUE
Logical, whether the Stock or Fleet object corresponds to natural origin or hatchery origin fish
Character indicating the corresponding salmon life stage of the Stock or Fleet object
Class multiHist object returned from MSEtool