| plot_LHG | R Documentation |
Plot the annual proportions of life history groups (natural origin fish) or release strategies (hatchery origin) at various life stages
plot_LHG(
SMSE,
var = "NOS",
type = c("prop", "abs"),
s = 1,
FUN = median,
figure = TRUE,
xlab = "Projection Year",
ylab,
name,
ylim
)
plot_RS(
SMSE,
var = "HOS",
type = c("prop", "abs"),
s = 1,
FUN = median,
figure = TRUE,
xlab = "Projection Year",
ylab,
name,
ylim
)
SMSE |
Class SMSE object returned by |
var |
Character. Slot for the state variables in |
type |
Character to indicate whether to plot proportion or absolute numbers |
s |
Integer. Population index for multi-population model (e.g., |
FUN |
Summarizing function across simulations, typically |
figure |
Logical, whether to generate a figure (set to FALSE if only using the function to return the data matrix) |
xlab |
Character. Name of time variable for the figure |
ylab |
Character. Name of the state variable for the figure |
name |
Character. Vector of names for the life history groups or release strategies |
ylim |
Vector length 2, y-axis limits |
Base graphics figure, barplot of distribution or total numbers by LHG or RS. Returns invisibly the matrix of plotted values
plot_statevar_ts()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.