| report | R Documentation |
Generate a markdown report for outcomes from a single operating model projection
## S4 method for signature 'SMSE'
report(
object,
name = object@Name,
filename = "SMSE",
dir = tempdir(),
open_file = TRUE,
render_args = list(),
...
)
object |
SMSE object |
name |
Character string for the model name to include in the report, e.g., model run number. |
filename |
Character string for the name of the markdown and HTML files. |
dir |
The directory in which the markdown and HTML files will be saved. |
open_file |
Logical, whether the HTML document is opened after it is rendered. |
render_args |
List of arguments to pass to |
... |
Additional arguments (not used) |
Returns invisibly the output of rmarkdown::render(), typically the path of the output file
compare()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.