salmonMSE: Run salmonMSE

View source: R/salmonMSE.R

salmonMSER Documentation

Run salmonMSE

Description

salmonMSE() runs a salmon management strategy evaluation from an operating model object (SOM), by checking the operating model object with check_SOM(), running the projection in ProjectSOM() (parallel if called upon, then stitches together the output in a single object), and calculates reference points with calc_ref().

ProjectSOM() is the internal projection function.

simple_salmonMSE() is helper function that converts a simple operating model (modeling only recruit-spawners with Ricker relationship, terminal marine fishery, without hatchery production) to a full operating model and runs the projection.

Usage

salmonMSE(SOM, ncores = 1, silent = FALSE)

ProjectSOM(SOM, sims, check = FALSE)

simple_salmonMSE(simpleSOM, ...)

Arguments

SOM

An object of class SOM

ncores

Integer, maximum number of processors to run projection with parallel processing

silent

Logical, whether to report progress in console

sims

Optional integer vector to run projection for a subset of simulations. Intended for parallel processing.

check

Logical, whether to check the structure of the input object with check_SOM()

simpleSOM

An object of class simpleSOM

...

Other arguments to pass to salmonMSE()

Value

SMSE object

Examples

## Not run: 
SMSE <- salmonMSE(simple_SOM)

## End(Not run)


salmonMSE documentation built on Aug. 20, 2026, 5:09 p.m.