Creates an operating model from MCMC samples and data inputs of the conditioning model. Management actions for habitat, hatchery production, and harvest still need to be specified in the operating model.
CM2SOM(stanfit, sims, nsim = 2, seed = 1, proyears = 40)SOM object.
Output from sample_CM()
Optional, a vector of integers indicating the MCMC iterations to convert to operating model simulations. Otherwise,
use argument nsim in order to sample a subset of the MCMC.
Integer, total number of simulations in the operating model. Only used if sims is missing.
Integer, seed for sampling the MCMC output. Only used if sims is missing.
Integer, the number of projection years in the operating model