| Effort_solver | R Documentation |
Internal solver used by catch_func() to calculate the fishing effort needed to achieve target harvest rate or catch rate,
subject to partial retention due to mark-selective fishing.
Harvest rate is discounted by adult equivalents for preterminal fisheries.
Effort_solver(
Eff,
N,
vul,
ret,
release_mort,
type = c("u", "catch"),
u = 0,
K = 0,
AEQ = array(1, dim(N)),
p_mature = array(1, dim(N))
)
Eff |
Numeric, fishing effort |
N |
Array |
vul |
Array |
ret |
Vector |
release_mort |
Vector |
type |
Character, either |
u |
Numeric, harvest rate target |
K |
Numeric, kept catch target |
AEQ |
Array |
p_mature |
Array |
Numeric. Returns the difference between the realized harvest rate (for the given value of Eff) and the target
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.