| Harvest-class | R Documentation |
"Harvest"The component of the operating model that controls marine harvest.
NameCharacter. Identifying name
type_PTCharacter. Whether to manage preterminal fishery catch from exploitation rate ("u") or catch target ("catch"). Default is "u".
type_TCharacter. Whether to manage terminal fishery catch from exploitation rate ("u") or catch target ("catch"). Default is "u".
u_preterminalNumeric, matrix [nsim, proyears], or function. If type_PT = "u", the harvest rate of the immature
component of the population in the pre-terminal fishery. The harvest rate is the ratio to kept AEQ catch to
(kept AEQ catch + return), where AEQ are adult equivalents. Function should be of the form function(NO, HO, m) return(u).
u_terminalNumeric, matrix [nsim, proyears], or function. If type_T = "u", the harvest rate (ratio of kept catch to
of the terminal marine fishery. Function should be of the form function(NO, HO, m) return(u).
K_PTNumeric or function. If type_PT = "catch", the catch target of the immature component of the population in the
pre-terminal fishery. Function should be of the form function(NO, HO, m) return(K).
K_TNumeric or function. If type_T = "catch", the catch target of the return in the terminal fishery.
Function should be of the form function(NO, HO, m) return(K).
MSF_PTLogical. Whether to implement mark-selective fishing in the preterminal fishery, with no retention on unmarked fish.
MSF_TLogical. Whether to implement mark-selective fishing in the terminal fishery, with no retention on unmarked fish.
release_mortVector length 2. The proportion of released fish that die after release, in the pre-terminal and terminal fishery.
Implemented to model mark-selective fishing. Not used if either MSF_PT or MSF_T is FALSE.
vulPTVector length maxage or matrix [nsim, maxage]. Vulnerability schedule (between 0-1) in the preterminal fishery. Values indicate
the proportion of fishing mortality experienced by each age class, where F_preterminal = -log(1 - u_preterminal).
vulTVector length maxage or matrix [nsim, maxage]. Vulnerability schedule (between 0-1) in the terminal fishery. Values indicate
the proportion of fishing mortality experienced by each age class, where F_terminal = -log(1 - u_terminal).
Objects can be created by calls of the form new("Harvest")
showClass("Harvest")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.