| Historical-class | R Documentation |
"Historical"Optional component of the operating model that specifies the historical dynamics. The default option starts the projection with 1000 natural-origin juveniles and 1000 hatchery-origin juveniles (if there is hatchery production) in the oldest age class, representing single-brood year returns since there is only one age class in the population. Specify the abundance in all age class to simulate multiple brood-year returns.
NameCharacter. Identifying name
InitNjuv_NOSArray by [nsim, maxage, n_g]. The abundance of immature natural origin fish at the beginning of the projection.
Default assumes 1000 in the oldest age class, which creates a population with single brood year returns.
InitNjuv_HOSArray by [nsim, maxage, n_r]. The abundance of immature hatchery origin fish at the beginning of the projection.
Default assumes 1000 in the oldest age class, which creates a population with single brood year returns.
Objects can be created by calls of the form new("Historical")
showClass("Historical")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.