"SHist"Stores the outputs from the historical reconstruction of salmon operating models.
NameCharacter. Identifying name
nyearsInteger. The number of historical years
nsimInteger. The number of simulations
nstocksInteger. The number of stocks
SnamesCharacter. Stock names
Egg_NOSArray [nsim, nstocks, nyears]. Spawning output, i.e., egg production, of natural origin spawners.
Egg_HOSArray [nsim, nstocks, nyears]. Spawning output of hatchery origin spawners.
SmoltArray [nsim, nstocks, nyears]. Natural smolt production (sum of offspring of natural and hatchery spawners).
Smolt_RelArray [nsim, nstocks, proyears]. Smolts that are offspring of broodtake, i.e., hatchery releases.
Njuv_NOSArray [nsim, nstocks, nage, nyears]. Abundance of juvenile natural origin fish at the beginning of the year.
Njuv_HOSArray [nsim, nstocks, nage, nyears]. Abundance of juvenile hatchery origin fish at the beginning of the year.
Return_NOSArray [nsim, nstocks, nage, nyears]. Mature fish that will be natural origin spawners.
Return_HOSArray [nsim, nstocks, nage, nyears]. Mature fish that will be hatchery origin spawners.
Escapement_NOSArray [nsim, nstocks, nage, nyears]. The escapement of mature fish that will be natural origin spawners.
Escapement_HOSArray [nsim, nstocks, nage, nyears]. The escapement of mature fish that will be hatchery origin spawners.
NOSArray [nsim, nstocks, proyears]. Natural origin spawners.
HOSArray [nsim, nstocks, proyears]. Hatchery origin spawners.
HOS_effectiveArray [nsim, nstocks, proyears]. Hatchery origin spawners discounted by gamma.
KPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery kept catch of natural origin spawners.
KT_NOSArray [nsim, nstocks, proyears]. Terminal fishery kept catch of natural origin spawners.
KPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery kept catch of hatchery origin spawners.
KT_HOSArray [nsim, nstocks, proyears]. Terminal fishery kept catch of hatchery origin spawners.
DPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery released catch (live and dead) of natural origin spawners.
DT_NOSArray [nsim, nstocks, proyears]. Terminal fishery released catch (live and dead) of natural origin spawners.
DPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery released catch (live and dead) of hatchery origin spawners.
DT_HOSArray [nsim, nstocks, proyears]. Terminal fishery released catch (live and dead) hatchery origin spawners.
UPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery harvest rate (from kept catch) of natural origin spawners.
UT_NOSArray [nsim, nstocks, proyears]. Terminal fishery harvest rate of natural origin spawners.
UPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery harvest rate of hatchery origin spawners.
UT_HOSArray [nsim, nstocks, proyears]. Terminal fishery harvest rate of hatchery origin spawners.
ExPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery exploitation rate (from kept catch and dead releases) of natural origin spawners.
ExT_NOSArray [nsim, nstocks, proyears]. Terminal fishery exploitation rate of natural origin spawners.
ExPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery exploitation rate of hatchery origin spawners.
ExT_HOSArray [nsim, nstocks, proyears]. Terminal fishery exploitation rate of hatchery origin spawners.
MiscList. Miscellaneous output