"SMSE"Stores the outputs from the simulation of salmon operating models.
NameCharacter. Identifying name
nyearsInteger. The number of historical years
proyearsInteger. The number of projected years
nsimInteger. The number of simulations
nstocksInteger. The number of stocks
SnamesCharacter. Stock names
Egg_NOSArray [nsim, nstocks, proyears]. Spawning output, i.e., egg production, of natural origin spawners.
Egg_HOSArray [nsim, nstocks, proyears]. Spawning output of hatchery origin spawners.
Fry_NOSArray [nsim, nstocks, proyears]. Fry that are offspring of natural origin spawners.
Fry_HOSArray [nsim, nstocks, proyears]. Fry that are offspring of hatchery origin spawners.
Smolt_NOSArray [nsim, nstocks, proyears]. Smolts that are offspring of natural origin spawners.
Smolt_HOSArray [nsim, nstocks, proyears]. Smolts that are offspring of hatchery origin spawners.
Smolt_RelArray [nsim, nstocks, proyears]. Smolts that are offspring of broodtake, i.e., hatchery releases.
Njuv_NOSArray [nsim, nstocks, nage, proyears]. Abundance of juvenile natural origin fish at the beginning of the year.
Njuv_HOSArray [nsim, nstocks, nage, proyears]. Abundance of juvenile hatchery origin fish at the beginning of the year.
Return_NOSArray [nsim, nstocks, nage, proyears]. Mature fish that will be natural origin spawners.
Return_HOSArray [nsim, nstocks, nage, proyears]. Mature fish that will be hatchery origin spawners.
Escapement_NOSArray [nsim, nstocks, nage, proyears]. The escapement of mature fish that will be natural origin spawners.
Escapement_HOSArray [nsim, nstocks, nage, proyears]. The escapement of mature fish that will be hatchery origin spawners.
NOBArray [nsim, nstocks, proyears]. Natural origin broodtake.
HOBArray [nsim, nstocks, proyears]. Hatchery origin broodtake (local + strays).
HOB_strayArray [nsim, nstocks, proyears]. Hatchery origin broodtake (strays only).
HOB_importArray [nsim, nstocks, proyears]. Imported hatchery origin broodtake used for hatchery production.
NOSArray [nsim, nstocks, nage, proyears]. Natural origin spawners.
HOSArray [nsim, nstocks, nage, proyears]. Hatchery origin spawners (local + strays).
HOS_strayArray [nsim, nstocks, nage, proyears]. Hatchery origin spawners (strays only).
HOS_effectiveArray [nsim, nstocks, nage, proyears]. Hatchery origin spawners (local + strays) discounted by gamma.
KPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery kept catch of natural origin spawners.
KT_NOSArray [nsim, nstocks, proyears]. Terminal fishery kept catch of natural origin spawners.
KPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery kept catch of hatchery origin spawners.
KT_HOSArray [nsim, nstocks, proyears]. Terminal fishery kept catch of hatchery origin spawners.
DPT_NOSArray [nsim, nstocks, proyears]. Pre-terminal fishery released catch (live and dead) of natural origin spawners.
DT_NOSArray [nsim, nstocks, proyears]. Terminal fishery released catch (live and dead) of natural origin spawners.
DPT_HOSArray [nsim, nstocks, proyears]. Pre-terminal fishery released catch (live and dead) of hatchery origin spawners.
DT_HOSArray [nsim, nstocks, proyears]. Terminal fishery released catch (live and dead) hatchery origin spawners.
UPT_NOSArray [nsim, nstocks, nage, proyears]. Pre-terminal fishery harvest rate (from kept catch) of natural origin spawners.
UT_NOSArray [nsim, nstocks, nage, proyears]. Terminal fishery harvest rate of natural origin spawners.
UPT_HOSArray [nsim, nstocks, nage, proyears]. Pre-terminal fishery harvest rate of hatchery origin spawners.
UT_HOSArray [nsim, nstocks, nage, proyears]. Terminal fishery harvest rate of hatchery origin spawners.
ExPT_NOSArray [nsim, nstocks, nage, proyears]. Pre-terminal fishery exploitation rate (from kept catch and dead releases) of natural origin spawners.
ExT_NOSArray [nsim, nstocks, nage, proyears]. Terminal fishery exploitation rate of natural origin spawners.
ExPT_HOSArray [nsim, nstocks, nage, proyears]. Pre-terminal fishery exploitation rate of hatchery origin spawners.
ExT_HOSArray [nsim, nstocks, nage, proyears]. Terminal fishery exploitation rate of hatchery origin spawners.
fitnessArray [nsim, nstocks, 2, proyears]. Fitness of the population in the natural (1) and hatchery (2) environments.
pNOBArray [nsim, nstocks, proyears]. Proportion of natural fish in the brood.
pHOS_censusArray [nsim, nstocks, proyears]. Proportion of spawners of hatchery origin, weighted by age class fecundity.
pHOS_effectiveArray [nsim, nstocks, proyears]. Proportion of spawners of hatchery origin, discounted by gamma, weighted by age class fecundity.
PNIArray [nsim, nstocks, proyears]. Proportionate natural influence, index of gene flow from hatchery to the natural environment.
p_wildArray [nsim, nstocks, proyears]. Proportion of wild spawners, natural spawners whose parents were also produced in the natural environment assuming
non-assortative mating, defined under Canada's Wild Salmon Policy.
Mjuv_lossArray [nsim, nstocks, nage, proyears]. Realized juvenile natural mortality, which may differ from inputs due to fitness loss.
MiscList. Miscellaneous output:
Ref for reference points
SHist for the SHist object
SOM for the SOM object.
LHG list nstocks long containing state variables by life history group
Objects can be created by calls of the form new("SMSE")
In generation \(t\), proportionate natural influence (PNI) is defined as:
$$\textrm{PNI}_t = \dfrac{p^\textrm{NOB}_t}{p^\textrm{NOB}_t + p^\textrm{HOSeff}_t}$$
with \(p^\textrm{HOSeff} = \textrm{HOSeff}/(\textrm{NOS} + \textrm{HOSeff})\).
The proportion of wild salmon is defined as:
$$p^{\textrm{WILD}}_t = q^\textrm{HOScen}_t \dfrac{(q^\textrm{HOScen}_{t-1})^2} {(q^\textrm{HOScen}_{t-1})^2 + 2\gamma \times p^\textrm{HOScen}_{t-1} q^\textrm{HOScen}_{t-1} + \gamma^2 (p^\textrm{HOScen}_{t-1})^2}$$
where \(q = 1-p\) and \(p^\textrm{HOScen} = \textrm{HOS}/(\textrm{NOS} + \textrm{HOS})\).
Withler et al. 2018. Genetically Based Targets for Enhanced Contributions to Canadian Pacific Chinook Salmon Populations. DFO Can. Sci. Advis. Sec. Res. Doc. 2018/019. xii + 88 p.