Converts from capacity/productivity parameters to alpha/beta stock-recruit parameters where productivity is in terms of smolts per spawner and alpha is terms of smolts per egg.
calc_SRRpars(p, capacity, f = 1, p_female = 1, type = c("BH", "Ricker", "HS"))Numeric vector length 2 for alpha and beta value, respectively
Numeric, the productivity parameter that sets the maximum survival as the initial abundance approaches zero
Numeric, the capacity parameter that set the maximum survivors
Fecundity, the spawning output per mature female
The proportion of females per spawner
Character, the functional form of the stock-recruit relationship
$$\alpha = \dfrac{P}{f \times p_{female}}$$
For the Beverton-Holt stock recruit relationship: $$\beta = \dfrac{\alpha}{C}$$
For the Ricker stock recruit relationship: $$\beta = \dfrac{\alpha}{Ce}$$, \(e\) is Euler's number.
calc_SRR()