Calculate the proportion of wild spawners from a time series of spawners
calc_pwild() is the simple calculation based on the proportion of hatchery spawners
calc_pwild_age() performs the calculation weighted by age class fecundity
calc_pwild(pHOS_cur, pHOS_prev, gamma)calc_pwild_age(NOS_a, HOS_a, fec, gamma)
calc_pwild_age() a matrix of pWILD by simulation and year. calc_pwild() returns a numeric
Numeric, proportion of hatchery spawners in current generation
Numeric, proportion of hatchery spawners in previous generation
Numeric, reduced reproductive success of hatchery spawners
Array [nsim, maxage, years] for natural spawners
Array [nsim, maxage, years] for hatchery spawners
Array [nsim, maxage, years] for age class fecundity