| calc_pwild | R Documentation |
Calculate the proportion of wild spawners from a time series of spawners
calc_pwild() is the simple calculation based on the proportion of hatchery spawners
calc_pwild_age() performs the calculation weighted by age class fecundity
calc_pwild(pHOS_cur, pHOS_prev, gamma)
calc_pwild_age(NOS_a, HOS_a, fec, gamma)
pHOS_cur |
Numeric, proportion of hatchery spawners in current generation |
pHOS_prev |
Numeric, proportion of hatchery spawners in previous generation |
gamma |
Numeric, reduced reproductive success of hatchery spawners |
NOS_a |
Array |
HOS_a |
Array |
fec |
Array |
calc_pwild_age() a matrix of pWILD by simulation and year. calc_pwild() returns a numeric
calc_pwild(0.9, 0.4, 0.8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.