View source: R/check_SOM.R View source: R/salmonMSE.R
| define_hatchery_args | R Documentation |
Internal functions that convert the operating model inputs into a list or data frame of parameters to pass on to other internal functions.
define_hatchery_args(SOM)
define_habitat_args(SOM)
define_fitness_args(SOM)
define_SRRpars(SOM)
SOM |
SOM operating model object |
define_hatchery_args() returns a length nstocks of hatchery parameters, in-river removals, and behavior of hatchery-origin
fish in the freshwater environment (fecundity, reproductive success, etc.)
define_habitat_args() returns a list of Habitat objects.
define_fitness_args() returns a length nstocks of fitness parameters.
define_SRRpars_args() returns a length nstocks, each of which is a data frame of stock-recruit parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.