Generate a markdown report to plot time series and MCMC posteriors of estimates from the conditioning model
report_CM(
stanfit,
year,
cov1_names,
cov_names,
rs_names,
name,
filename = "CM",
dir = tempdir(),
open_file = TRUE,
render_args = list(),
...
)Returns invisibly the output of rmarkdown::render(), typically the path of the output file
Output from sample_CM()
Optional vector of calendar years
Optional character vector for names of covariates that predict age-1 natural mortality
Optional character vector for names of covariates that predict age-2+ natural mortality
Optional character vector for names of hatchery release strategies
Optional character string for the model name to include in the report, e.g., model run number
Character string for the name of the markdown and HTML files
The directory in which the markdown and HTML files will be saved.
Logical, whether the HTML document is opened after it is rendered
List of arguments to pass to rmarkdown::render()
Additional arguments (not used)
Report excludes MCMC values from warmup iterations
fit_CM()