salmonMSE() runs a salmon management strategy evaluation through the following steps:
Converts a salmon operating model (SOM) to a multi-stock operating model (MSEtool::MOM) via SOM2MOM()
Creates a harvest management procedure specifying the harvest control rule
Generates the historical reconstruction of the state variables
Runs projection (if Hist = FALSE)
Converts the openMSE output, along with additional state variables recorded in salmonMSE_env, into a salmon MSE object (SMSE) via MMSE2SMSE()
salmonMSE(SOM, Hist = FALSE, silent = FALSE, trace = FALSE, convert = TRUE)If Hist = TRUE: if convert = TRUE, a SHist object or if convert = FALSE, a multiHist object (list).
If Hist = FALSE: if convert = TRUE, a SMSE object or if convert = FALSE, a MSEtool::MMSE object.
An object of class SOM
Logical, whether to stop the function stop after historical simulations?
Logical, whether to report progress in console
Logical, whether to report additional messages from openMSE
Logical, whether to convert the output into a salmon MSE (SHist or SMSE, depending on Hist) object