| simpleSOM-class | R Documentation |
"simpleSOM"A simple operating model for modeling recruit-spawners and a terminal marine fishery, no hatchery production.
Various parameters can be stochastic (length nsim) or input as a single numeric
(value identical across all simulations).
NameCharacter. Identifying name
nsimInteger. Number of simulations.
maxageInteger. The maximum age of the population age structure.
ngenInteger. The number of generations (life cycles) to run the projection.
kappaVector length nsim. The adult productivity ratio for the stock-recruit function. Units of recruits per spawner.
Natural per-capita production of recruits as the population approaches zero (density-independent component).
SmaxVector length nsim. The spawner abundance that maximizes smolt production in the Ricker stock-recruit function. Units of spawners.
sigmaRVector length nsim. The lognormal standard deviation in the Ricker stock-recruit relationship. Recruitment anomalies
will be simulated with [stats::rlnorm()].
RecdevOptional matrix [nsim, ngen-1] of recruitment anomalies in the Ricker stock-recruit relationship. Overrides the sigmaR argument
and provides more user flexibility, for example, simulating with auto-correlation.
type_TCharacter. Whether to manage terminal fishery catch from exploitation rate ("u") or catch target ("catch"). Default is "u".
u_terminalNumeric, matrix [nsim, proyears], or function. If type_T = "u", the harvest rate (ratio of kept catch to
of the terminal marine fishery. Function should be of the form function(NO, HO, m) return(u).
K_TNumeric or function. If type_T = "catch", the catch target of the return in the terminal fishery.
Function should be of the form function(NO, HO, m) return(K).
InitReturnSingle numeric or vector [nsim]. The return at the beginning of the projection. Default assumes 1000.
Objects can be created by calls of the form new("simpleSOM")
showClass("simpleSOM")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.