| stray_func | R Documentation |
Calculates the number of fish that move from donor to recipient populations from a movement matrix
stray_func(N, stray_matrix, m)
N |
Array |
stray_matrix |
Matrix |
m |
Vector |
Named list:
N_remain Abundance of hatchery-origin fish that do not stray, same dimension as N
N_stray Abundance of strays by recipient population, same dimension as N
m_stray Mark rate of strays by recipient population, vector [ns]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.